@@ -3,8 +3,8 @@ use std::net::SocketAddr;
 use std::pin::Pin;
 use std::sync::Arc;
 
-use once_cell::sync::Lazy;
 use futures::future;
+use once_cell::sync::Lazy;
 
 use crate::catcher;
 use crate::http::header::CONTENT_TYPE;
@@ -13,7 +13,7 @@ use crate::routing::{PathState, Router};
 use crate::transport::Transport;
 use crate::{Catcher, Depot};
 
-static DEFAULT_CATCHERS: Lazy<Arc<Vec<Box<dyn Catcher>>>> = Lazy::new(|| Arc::new(catcher::defaults::get()));
+static DEFAULT_CATCHERS: Lazy<Vec<Box<dyn Catcher>>> = Lazy::new(catcher::defaults::get);
 pub struct Service {
     pub(crate) router: Arc<Router>,
     pub(crate) catchers: Arc<Vec<Box<dyn Catcher>>>,
@@ -34,6 +34,8 @@ impl Service {
     pub fn router(&self) -> Arc<Router> {
         self.router.clone()
     }
+    /// when the response code is 400-600 and the body is empty, capture and set the return value.
+    /// By default, it is the built-in default html page.
     pub fn with_catchers<T>(mut self, catchers: T) -> Self
     where
         T: Into<Arc<Vec<Box<dyn Catcher>>>>,
@@ -111,7 +113,7 @@ impl hyper::service::Service<hyper::Request<hyper::body::Body>> for HyperHandler
                 request.params = path_state.params;
                 for handler in [&dm.befores[..], &[dm.handler]].concat() {
                     handler.handle(&mut request, &mut depot, &mut response).await;
-                    if response.is_commited() {
+                    if response.is_committed() {
                         break;
                     }
                 }
@@ -119,9 +121,7 @@ impl hyper::service::Service<hyper::Request<hyper::body::Body>> for HyperHandler
                 for handler in &dm.afters {
                     handler.handle(&mut request, &mut depot, &mut response).await;
                 }
-                if !response.is_commited() {
-                    response.commit();
-                }
+                response.commit();
             } else {
                 response.set_status_code(StatusCode::NOT_FOUND);
             }
@@ -135,6 +135,7 @@ impl hyper::service::Service<hyper::Request<hyper::body::Body>> for HyperHandler
                     response.set_status_code(StatusCode::OK);
                 }
             }
+
             let status = response.status_code().unwrap();
             let has_error = status.is_client_error() || status.is_server_error();
             if let Some(value) = response.headers().get(CONTENT_TYPE) {
@@ -165,20 +166,11 @@ impl hyper::service::Service<hyper::Request<hyper::body::Body>> for HyperHandler
                 );
             }
             if response.body.is_none() && has_error {
-                let mut catched = false;
-                for catcher in &*catchers {
+                for catcher in catchers.iter().chain(DEFAULT_CATCHERS.iter()) {
                     if catcher.catch(&request, &mut response) {
-                        catched = true;
                         break;
                     }
                 }
-                if !catched {
-                    for catcher in &**DEFAULT_CATCHERS {
-                        if catcher.catch(&request, &mut response) {
-                            break;
-                        }
-                    }
-                }
             }
             response.write_back(&mut request, &mut hyper_response).await;
             Ok(hyper_response)
